pub enum FirstRunStatus {
FirstRun,
SubsequentRun {
state: BugbotState,
},
}Expand description
Result of checking whether this is a first run.
Variants
FirstRun
No prior state exists. Baselines need to be built.
SubsequentRun
State exists and baselines have been built previously.
Fields

state: BugbotStateThe persisted state from the previous run.
Implementations
Sourceimpl FirstRunStatus
impl FirstRunStatus
Sourcepub fn is_first_run(&self) -> bool
pub fn is_first_run(&self) -> bool
Returns true if this is the first run (no prior state).