Module tools

Module tools 

L1 commodity tool types and conversion impls

Defines types for the L1 diagnostic tool orchestration layer:

  • ToolCategory: classification of tools (linter, security scanner, etc.)
  • ToolConfig: static configuration for a single diagnostic tool
  • ToolResult: execution result from running a tool
  • L1Finding: raw finding from a tool before conversion to BugbotFinding

Structs

L1Finding
L1 finding from a commodity tool before conversion to BugbotFinding.
ToolConfig
Configuration for a single diagnostic tool
ToolRegistry
Registry of commodity diagnostic tools per language.
ToolResult
Result from running a single tool

Enums

ToolCategory
Category of commodity diagnostic tool