Module error

Module error 

Error types for Contracts & Flow commands

Provides specific error types for all failure modes in the contracts and flow analysis commands. Errors include actionable information like file paths and line numbers.

Enums

ContractsError
Errors specific to contracts and flow analysis commands.

Type Aliases

ContractsResult
Result type for contracts commands.