is_test_function_node

Function is_test_function_node 

pub fn is_test_function_node(
    node: &Node<'_>,
    source: &[u8],
    language: Language,
) -> bool
Public wrapper around the per-language test-function predicate.

tldr specs --from-tests re-uses this from the generic spec extractor so the same definition of “test function” used to count tests is used to harvest assertions inside them.