pub async fn start_daemon_background(project: &Path) -> DaemonResult<u32>Expand description
Start a daemon in the background for the given project.
Returns the PID of the daemon process.
pub async fn start_daemon_background(project: &Path) -> DaemonResult<u32>Start a daemon in the background for the given project.
Returns the PID of the daemon process.