pub async fn wait_for_daemon(
project: &Path,
timeout_secs: u64,
) -> DaemonResult<()>Expand description
Wait for a daemon to become ready by polling the socket.
Returns Ok(()) if the daemon becomes available within the timeout.
pub async fn wait_for_daemon(
project: &Path,
timeout_secs: u64,
) -> DaemonResult<()>Wait for a daemon to become ready by polling the socket.
Returns Ok(()) if the daemon becomes available within the timeout.