pub async fn send_command(
project: &Path,
cmd: &DaemonCommand,
) -> DaemonResult<DaemonResponse>Expand description
Send a command to the daemon and receive a response.
Convenience function that handles connection, send, and receive.
pub async fn send_command(
project: &Path,
cmd: &DaemonCommand,
) -> DaemonResult<DaemonResponse>Send a command to the daemon and receive a response.
Convenience function that handles connection, send, and receive.