pub async fn send_raw_command(
project: &Path,
json: &str,
) -> DaemonResult<String>Expand description
Send a raw JSON command to the daemon and receive a raw response.
Useful for low-level debugging or custom commands.
pub async fn send_raw_command(
project: &Path,
json: &str,
) -> DaemonResult<String>Send a raw JSON command to the daemon and receive a raw response.
Useful for low-level debugging or custom commands.