pub async fn send_response(
stream: &mut IpcStream,
response: &DaemonResponse,
) -> DaemonResult<()>Expand description
Send a response to a client connection.
Used by the daemon to respond to client commands.
pub async fn send_response(
stream: &mut IpcStream,
response: &DaemonResponse,
) -> DaemonResult<()>Send a response to a client connection.
Used by the daemon to respond to client commands.