pub fn extract_interface_with_lang(
path: &Path,
source: &str,
lang: Language,
) -> PatternsResult<InterfaceInfo>Expand description
Extract the public interface from a source file with an explicit language.
pub fn extract_interface_with_lang(
path: &Path,
source: &str,
lang: Language,
) -> PatternsResult<InterfaceInfo>Extract the public interface from a source file with an explicit language.