pub struct CycleDetector { /* private fields */ }Expand description
Cycle detector for graph traversal operations
Tracks visited (file, function) pairs to detect cycles during call graph traversal, import resolution, or other graph operations.
Example
ⓘ
use tldr_cli::commands::remaining::graph_utils::CycleDetector;
use std::path::Path;
let mut detector = CycleDetector::new();
// First visit returns false (no cycle)
assert!(!detector.visit(Path::new("a.py"), "func"));
// Visiting same location returns true (cycle detected)
assert!(detector.visit(Path::new("a.py"), "func"));Implementations
Sourceimpl CycleDetector
impl CycleDetector
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Create a cycle detector with a specific capacity hint
Sourcepub fn visit(&mut self, file: &Path, func: &str) -> bool
pub fn visit(&mut self, file: &Path, func: &str) -> bool
Visit a (file, function) pair.
Returns true if this location was already visited (cycle detected).
Returns false if this is a new location.
Sourcepub fn visit_file(&mut self, file: &Path) -> bool
pub fn visit_file(&mut self, file: &Path) -> bool
Visit a file path only (for import resolution)
Sourcepub fn is_cycle_detected(&self) -> bool
pub fn is_cycle_detected(&self) -> bool
Check if a cycle has been detected during traversal
Sourcepub fn visited_count(&self) -> usize
pub fn visited_count(&self) -> usize
Get the number of visited locations
Sourcepub fn was_visited(&self, file: &Path, func: &str) -> bool
pub fn was_visited(&self, file: &Path, func: &str) -> bool
Check if a specific location has been visited
Sourcepub fn visited_files(&self) -> Vec<PathBuf>
pub fn visited_files(&self) -> Vec<PathBuf>
Get all visited files (unique)
Sourcepub fn enter_depth(&mut self) -> bool
pub fn enter_depth(&mut self) -> bool
Enter a new depth level. Returns false if max depth exceeded.
Sourcepub fn exit_depth(&mut self)
pub fn exit_depth(&mut self)
Exit a depth level
Sourcepub fn current_depth(&self) -> usize
pub fn current_depth(&self) -> usize
Get current depth