pub struct SmellsArgs {
pub path: PathBuf,
pub threshold: ThresholdPresetArg,
pub smell_type: Option<SmellTypeArg>,
pub suggest: bool,
pub deep: bool,
}Expand description
Detect code smells
Fields
path: PathBufPath to analyze (file or directory)
threshold: ThresholdPresetArgThreshold preset
smell_type: Option<SmellTypeArg>Filter by smell type
suggest: boolInclude suggestions for fixing
deep: boolDeep analysis: aggregate findings from cohesion, coupling, dead code, similarity, and cognitive complexity analyzers in addition to the standard smell detectors
Implementations
Sourceimpl SmellsArgs
impl SmellsArgs