common_path_prefix

Function common_path_prefix 

pub fn common_path_prefix(paths: &[&Path]) -> PathBuf
Compute the common directory prefix of a list of paths. Returns the longest shared directory ancestor (never a partial component). Returns empty path if paths share no common ancestor.