Git change detection for bugbot
Detects files changed via git, filtered to the target language.
Uses direct git commands to list changed files – no call graph needed.
Structs
- Change
Detection Result - Result of detecting changed files in the project.
Functions
- detect_
changes - Detect changed files in
project, filtered to the givenlanguage.