pub async fn read_command(stream: &mut IpcStream) -> DaemonResult<DaemonCommand>Expand description
Read a command from a client connection.
Used by the daemon to receive commands from clients.
pub async fn read_command(stream: &mut IpcStream) -> DaemonResult<DaemonCommand>Read a command from a client connection.
Used by the daemon to receive commands from clients.